@@ -24,6 +24,7 @@ from .utils import SKIP_IN_PATH, _quote, _rewrite_parameters
 
 
 class AsyncSearchClient(NamespacedClient):
+
     @_rewrite_parameters()
     def delete(
         self,
@@ -35,16 +36,20 @@ class AsyncSearchClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes an async search by ID. If the search is still running, the search request
-        will be cancelled. Otherwise, the saved search results are deleted.
+        Deletes an async search by identifier. If the search is still running, the search
+        request will be cancelled. Otherwise, the saved search results are deleted. If
+        the Elasticsearch security features are enabled, the deletion of a specific async
+        search is restricted to: the authenticated user that submitted the original search
+        request; users that have the `cancel_task` cluster privilege.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.12/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/async-search.html>`_
 
         :param id: A unique identifier for the async search.
         """
         if id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'id'")
-        __path = f"/_async_search/{_quote(id)}"
+        __path_parts: t.Dict[str, str] = {"id": _quote(id)}
+        __path = f'/_async_search/{__path_parts["id"]}'
         __query: t.Dict[str, t.Any] = {}
         if error_trace is not None:
             __query["error_trace"] = error_trace
@@ -56,7 +61,12 @@ class AsyncSearchClient(NamespacedClient):
             __query["pretty"] = pretty
         __headers = {"accept": "application/json"}
         return self.perform_request(  # type: ignore[return-value]
-            "DELETE", __path, params=__query, headers=__headers
+            "DELETE",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="async_search.delete",
+            path_parts=__path_parts,
         )
 
     @_rewrite_parameters()
@@ -67,18 +77,20 @@ class AsyncSearchClient(NamespacedClient):
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         human: t.Optional[bool] = None,
-        keep_alive: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        keep_alive: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         pretty: t.Optional[bool] = None,
         typed_keys: t.Optional[bool] = None,
         wait_for_completion_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+            t.Union[str, t.Literal[-1], t.Literal[0]]
         ] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
         Retrieves the results of a previously submitted async search request given its
-        ID.
+        identifier. If the Elasticsearch security features are enabled, access to the
+        results of a specific async search is restricted to the user or API key that
+        submitted it.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.12/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/async-search.html>`_
 
         :param id: A unique identifier for the async search.
         :param keep_alive: Specifies how long the async search should be available in
@@ -98,7 +110,8 @@ class AsyncSearchClient(NamespacedClient):
         """
         if id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'id'")
-        __path = f"/_async_search/{_quote(id)}"
+        __path_parts: t.Dict[str, str] = {"id": _quote(id)}
+        __path = f'/_async_search/{__path_parts["id"]}'
         __query: t.Dict[str, t.Any] = {}
         if error_trace is not None:
             __query["error_trace"] = error_trace
@@ -116,7 +129,12 @@ class AsyncSearchClient(NamespacedClient):
             __query["wait_for_completion_timeout"] = wait_for_completion_timeout
         __headers = {"accept": "application/json"}
         return self.perform_request(  # type: ignore[return-value]
-            "GET", __path, params=__query, headers=__headers
+            "GET",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="async_search.get",
+            path_parts=__path_parts,
         )
 
     @_rewrite_parameters()
@@ -130,16 +148,19 @@ class AsyncSearchClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retrieves the status of a previously submitted async search request given its
-        ID.
+        Get async search status Retrieves the status of a previously submitted async
+        search request given its identifier, without retrieving search results. If the
+        Elasticsearch security features are enabled, use of this API is restricted to
+        the `monitoring_user` role.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.12/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/async-search.html>`_
 
         :param id: A unique identifier for the async search.
         """
         if id in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'id'")
-        __path = f"/_async_search/status/{_quote(id)}"
+        __path_parts: t.Dict[str, str] = {"id": _quote(id)}
+        __path = f'/_async_search/status/{__path_parts["id"]}'
         __query: t.Dict[str, t.Any] = {}
         if error_trace is not None:
             __query["error_trace"] = error_trace
@@ -151,7 +172,12 @@ class AsyncSearchClient(NamespacedClient):
             __query["pretty"] = pretty
         __headers = {"accept": "application/json"}
         return self.perform_request(  # type: ignore[return-value]
-            "GET", __path, params=__query, headers=__headers
+            "GET",
+            __path,
+            params=__query,
+            headers=__headers,
+            endpoint_id="async_search.status",
+            path_parts=__path_parts,
         )
 
     @_rewrite_parameters(
@@ -210,16 +236,16 @@ class AsyncSearchClient(NamespacedClient):
         batched_reduce_size: t.Optional[int] = None,
         ccs_minimize_roundtrips: t.Optional[bool] = None,
         collapse: t.Optional[t.Mapping[str, t.Any]] = None,
-        default_operator: t.Optional[t.Union["t.Literal['and', 'or']", str]] = None,
+        default_operator: t.Optional[t.Union[str, t.Literal["and", "or"]]] = None,
         df: t.Optional[str] = None,
         docvalue_fields: t.Optional[t.Sequence[t.Mapping[str, t.Any]]] = None,
         error_trace: t.Optional[bool] = None,
         expand_wildcards: t.Optional[
             t.Union[
                 t.Sequence[
-                    t.Union["t.Literal['all', 'closed', 'hidden', 'none', 'open']", str]
+                    t.Union[str, t.Literal["all", "closed", "hidden", "none", "open"]]
                 ],
-                t.Union["t.Literal['all', 'closed', 'hidden', 'none', 'open']", str],
+                t.Union[str, t.Literal["all", "closed", "hidden", "none", "open"]],
             ]
         ] = None,
         explain: t.Optional[bool] = None,
@@ -232,7 +258,7 @@ class AsyncSearchClient(NamespacedClient):
         ignore_throttled: t.Optional[bool] = None,
         ignore_unavailable: t.Optional[bool] = None,
         indices_boost: t.Optional[t.Sequence[t.Mapping[str, float]]] = None,
-        keep_alive: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        keep_alive: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         keep_on_completion: t.Optional[bool] = None,
         knn: t.Optional[
             t.Union[t.Mapping[str, t.Any], t.Sequence[t.Mapping[str, t.Any]]]
@@ -257,12 +283,12 @@ class AsyncSearchClient(NamespacedClient):
         routing: t.Optional[str] = None,
         runtime_mappings: t.Optional[t.Mapping[str, t.Mapping[str, t.Any]]] = None,
         script_fields: t.Optional[t.Mapping[str, t.Mapping[str, t.Any]]] = None,
-        scroll: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
+        scroll: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
         search_after: t.Optional[
             t.Sequence[t.Union[None, bool, float, int, str, t.Any]]
         ] = None,
         search_type: t.Optional[
-            t.Union["t.Literal['dfs_query_then_fetch', 'query_then_fetch']", str]
+            t.Union[str, t.Literal["dfs_query_then_fetch", "query_then_fetch"]]
         ] = None,
         seq_no_primary_term: t.Optional[bool] = None,
         size: t.Optional[int] = None,
@@ -281,7 +307,7 @@ class AsyncSearchClient(NamespacedClient):
         suggest: t.Optional[t.Mapping[str, t.Any]] = None,
         suggest_field: t.Optional[str] = None,
         suggest_mode: t.Optional[
-            t.Union["t.Literal['always', 'missing', 'popular']", str]
+            t.Union[str, t.Literal["always", "missing", "popular"]]
         ] = None,
         suggest_size: t.Optional[int] = None,
         suggest_text: t.Optional[str] = None,
@@ -292,14 +318,22 @@ class AsyncSearchClient(NamespacedClient):
         typed_keys: t.Optional[bool] = None,
         version: t.Optional[bool] = None,
         wait_for_completion_timeout: t.Optional[
-            t.Union["t.Literal[-1]", "t.Literal[0]", str]
+            t.Union[str, t.Literal[-1], t.Literal[0]]
         ] = None,
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Executes a search request asynchronously.
+        Runs a search request asynchronously. When the primary sort of the results is
+        an indexed field, shards get sorted based on minimum and maximum value that they
+        hold for that field, hence partial results become available following the sort
+        criteria that was requested. Warning: Async search does not support scroll nor
+        search requests that only include the suggest section. By default, Elasticsearch
+        doesn’t allow you to store an async search response larger than 10Mb and an attempt
+        to do this results in an error. The maximum allowed size for a stored async search
+        response can be set by changing the `search.max_async_search_response_size` cluster
+        level setting.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.12/async-search.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/async-search.html>`_
 
         :param index: A comma-separated list of index names to search; use `_all` or
             empty string to perform the operation on all indices
@@ -427,9 +461,12 @@ class AsyncSearchClient(NamespacedClient):
             up to a certain timeout. When the async search completes within the timeout,
             the response won’t include the ID as the results are not stored in the cluster.
         """
+        __path_parts: t.Dict[str, str]
         if index not in SKIP_IN_PATH:
-            __path = f"/{_quote(index)}/_async_search"
+            __path_parts = {"index": _quote(index)}
+            __path = f'/{__path_parts["index"]}/_async_search'
         else:
+            __path_parts = {}
             __path = "/_async_search"
         __query: t.Dict[str, t.Any] = {}
         __body: t.Dict[str, t.Any] = body if body is not None else {}
@@ -589,5 +626,11 @@ class AsyncSearchClient(NamespacedClient):
         if __body is not None:
             __headers["content-type"] = "application/json"
         return self.perform_request(  # type: ignore[return-value]
-            "POST", __path, params=__query, headers=__headers, body=__body
+            "POST",
+            __path,
+            params=__query,
+            headers=__headers,
+            body=__body,
+            endpoint_id="async_search.submit",
+            path_parts=__path_parts,
         )
